@@ -26,64 +26,31 @@
 
 This AWS Solutions Construct implements a pattern Amazon DynamoDB table with stream to invoke the AWS Lambda function  with the least privileged permissions.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { DynamoDBStreamsToLambdaProps,  DynamoDBStreamsToLambda} from '@aws-solutions-constructs/aws-dynamodbstreams-lambda';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new DynamoDBStreamsToLambda(this, 'test-dynamodbstreams-lambda', {
   lambdaFunctionProps: {
-      code: lambda.Code.fromAsset(`lambda`),
+      code: lambda.Code.fromAsset(`${__dirname}/lambda`),
       runtime: lambda.Runtime.NODEJS_14_X,
       handler: 'index.handler'
   },
 });
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_dynamodbstreams_lambda import DynamoDBStreamsToLambda
-from aws_cdk import (
-  aws_lambda as _lambda,
-  Stack
-)
-from constructs import Construct
-
-DynamoDBStreamsToLambda(self, 'test-dynamodbstreams-lambda',
-                        lambda_function_props=_lambda.FunctionProps(
-                            code=_lambda.Code.from_asset('lambda'),
-                            runtime=_lambda.Runtime.PYTHON_3_9,
-                            handler='index.handler'
-                        )
-                        )
+```text
+new DynamoDBStreamsToLambda(scope: Construct, id: string, props: DynamoDBStreamsToLambdaProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.dynamodbstreamslambda.*;
-
-new DynamoDBStreamsToLambda(this, "test-dynamodbstreams-lambda",
-        new DynamoDBStreamsToLambdaProps.Builder()
-                .lambdaFunctionProps(new FunctionProps.Builder()
-                        .runtime(Runtime.NODEJS_14_X)
-                        .code(Code.fromAsset("lambda"))
-                        .handler("index.handler")
-                        .build())
-                .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`DynamoDBStreamsToLambdaProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -136,7 +103,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -153,17 +120,17 @@ from ._jsii import *
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class DynamoDBStreamsToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-dynamodbstreams-lambda.DynamoDBStreamsToLambda",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
